@@ -65,7 +65,7 @@ from repo_helper_github.options import token_option, version_callback
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.4.0"
+__version__: str = "0.4.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = [
@@ -119,7 +119,7 @@ class GitHubManager(RepoHelper):
 	:param verbose: Whether to show information on the GitHub API rate limit.
 	:param colour: Whether to use coloured output.
 
-	.. versionchanged:: 0.4.0
+	.. versionchanged:: 0.4.1
 
 		Added the ``verbose`` and ``colour`` options.
 	"""  # noqa: D400
@@ -131,14 +131,14 @@ class GitHubManager(RepoHelper):
 	"""
 	Whether to show information on the GitHub API rate limit.
 
-	.. versionadded: 0.4.0
+	.. versionadded: 0.4.1
 	"""
 
 	colour: Optional[bool]
 	"""
 	Whether to use coloured output.
 
-	.. versionadded: 0.4.0
+	.. versionadded: 0.4.1
 	"""
 
 	def __init__(
@@ -170,11 +170,11 @@ class GitHubManager(RepoHelper):
 		:param org: Whether the repository should be created for the organisation set as ``username``,
 			or for the authenticated user (default).
 
-		.. versionchanged:: 0.4.0
+		.. versionchanged:: 0.4.1
 
 			Removed the ``verbose`` option. Provide it to the class constructor instead.
 
-		.. versionchanged:: 0.4.0  Added the ``org`` argument.
+		.. versionchanged:: 0.4.1  Added the ``org`` argument.
 		"""
 
 		with self.echo_rate_limit():
@@ -209,11 +209,11 @@ class GitHubManager(RepoHelper):
 		:param org: Whether the repository should be created for the organisation set as ``username``,
 			or for the authenticated user (default).
 
-		.. versionchanged:: 0.4.0
+		.. versionchanged:: 0.4.1
 
 			Removed the ``verbose`` option. Provide it to the class constructor instead.
 
-		.. versionchanged:: 0.4.0  Added the ``org`` argument.
+		.. versionchanged:: 0.4.1  Added the ``org`` argument.
 		"""
 
 		with self.echo_rate_limit():
@@ -241,7 +241,7 @@ class GitHubManager(RepoHelper):
 
 		:param org:
 
-		.. versionadded:: 0.4.0
+		.. versionadded:: 0.4.1
 		"""  # noqa: D400
 
 		user = self.github.get_user()
@@ -270,9 +270,9 @@ class GitHubManager(RepoHelper):
 
 		``PYPI_TOKEN`` and ``ANACONDA_TOKEN`` can either be passed as keyword arguments to this function or provided at the interactive prompt.
 
-		.. versionadded:: 0.4.0
+		.. versionadded:: 0.4.1
 
-		.. versionchanged:: 0.4.0  Add ``overwrite``, ``PYPI_TOKEN``, ``ANACONDA_TOKEN`` options.
+		.. versionchanged:: 0.4.1  Add ``overwrite``, ``PYPI_TOKEN``, ``ANACONDA_TOKEN`` options.
 		"""
 
 		with self.echo_rate_limit():
@@ -343,7 +343,7 @@ class GitHubManager(RepoHelper):
 		:param org: Whether the repository should be created for the organisation set as ``username``,
 			or for the authenticated user (default).
 
-		.. versionadded:: 0.4.0
+		.. versionadded:: 0.4.1
 		"""
 
 		with self.echo_rate_limit():
@@ -456,7 +456,7 @@ def encrypt_secret(public_key: str, secret_value: str) -> str:
 	:param public_key:
 	:param secret_value:
 
-	.. versionadded: 0.4.0
+	.. versionadded: 0.4.1
 	"""
 
 	public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
@@ -471,7 +471,7 @@ def compile_required_checks(repo: RepoHelper) -> Iterator[str]:
 
 	:param repo:
 
-	.. versionadded:: 0.4.0
+	.. versionadded:: 0.4.1
 	"""
 
 	actions_manager = ActionsManager(repo.target_repo, repo.templates)
@@ -500,7 +500,7 @@ def compile_required_checks(repo: RepoHelper) -> Iterator[str]:
 
 	yield from ["mypy / ubuntu-latest", "Flake8"]
 
-	if repo.templates.globals["enable_tests"]:
+	if repo.templates.globals["enable_docs"]:
 		yield "docs"
 
 
@@ -520,7 +520,7 @@ class IsolatedGitHubManager(GitHubManager):
 	:param verbose: Whether to show information on the GitHub API rate limit.
 	:param colour: Whether to use coloured output.
 
-	.. versionadded:: 0.4.0
+	.. versionadded:: 0.4.1
 	"""  # noqa: D400
 
 	def __init__(
